@@ -1,5 +1,5 @@
 /**
- * @file conf.h Liferea configuration (gconf access)
+ * @file conf.h  Liferea configuration (gconf access)
  *
  * Copyright (C) 2003-2009 Lars Lindner <lars.lindner@gmail.com>
  * Copyright (C) 2004,2005 Nathan J. Conrad <t98502@users.sourceforge.net>
@@ -39,10 +39,10 @@
 #define REFOCUS_TIMEOUT			"/apps/liferea/refocus-timeout"
 #define DISABLE_JAVASCRIPT		"/apps/liferea/disable-javascript"
 #define SOCIAL_BM_SITE			"/apps/liferea/social-bm-site"
-#define SOCIAL_BM_HIDE_LINK		"/apps/liferea/social-bm-hide-link"
-#define SEARCH_ENGINE			"/apps/liferea/search-engine"
-#define SEARCH_ENGINE_HIDE_LINK		"/apps/liferea/search-engine-hide-link"
-#define ALLOW_FLASH			"/apps/liferea/allow-flash"
+#define SOCIAL_BM_HIDE			"/apps/liferea/social-bm-hide"
+#define SOCIAL_LINK_SEARCH_SITE		"/apps/liferea/social-link-search-site"
+#define SOCIAL_LINK_SEARCH_HIDE		"/apps/liferea/social-link-search-hide"
+#define ENABLE_PLUGINS			"/apps/liferea/enable-plugins"
 
 /* enclosure handling */
 #define ENCLOSURE_DOWNLOAD_TOOL		"/apps/liferea/enclosure-download-tool"
@@ -55,20 +55,20 @@
 #define DEFAULT_MAX_ITEMS		"/apps/liferea/maxitemcount"
 #define DEFAULT_UPDATE_INTERVAL		"/apps/liferea/default-update-interval"
 #define STARTUP_FEED_ACTION		"/apps/liferea/startup_feed_action"
-#define UPDATE_THREAD_CONCURRENCY	"/apps/liferea/update-thread-concurrency"
 #define ENABLE_FETCH_RETRIES		"/apps/liferea/enable-fetch-retries"
 
 /* folder handling settings */
 #define FOLDER_DISPLAY_MODE		"/apps/liferea/folder-display-mode"
 #define FOLDER_DISPLAY_HIDE_READ	"/apps/liferea/folder-display-hide-read"
+#define REDUCED_FEEDLIST		"/apps/liferea/reduced-feedlist"
 
 /* GUI settings and persistency values */
 #define SHOW_TRAY_ICON			"/apps/liferea/trayicon"
 #define SHOW_NEW_COUNT_IN_TRAY		"/apps/liferea/trayicon-new-count"
 #define DONT_MINIMIZE_TO_TRAY		"/apps/liferea/dont-minimize-to-tray"
+#define START_IN_TRAY			"/apps/liferea/start-in-tray"
 #define SHOW_POPUP_WINDOWS		"/apps/liferea/show-popup-windows"
 #define POPUP_PLACEMENT			"/apps/liferea/popup-placement"
-#define DISABLE_MENUBAR			"/apps/liferea/disable-menubar"
 #define DISABLE_TOOLBAR			"/apps/liferea/disable-toolbar"
 #define TOOLBAR_STYLE			"/apps/liferea/toolbar-style"
 #define LAST_WINDOW_X			"/apps/liferea/last-window-x"
@@ -99,6 +99,9 @@
 
 /* other settings */
 #define DISABLE_DBUS			"/apps/liferea/disable-dbus"
+#define SYNC_AVAHI_ENABLED		"/apps/liferea/sync/use_avahi"
+#define SYNC_AVAHI_SERVICE_NAME		"/apps/liferea/sync/avahi_service_name"
+#define SYNC_AVAHI_PASSWORD		"/apps/liferea/sync/avahi_password"
 
 /* initializing methods */
 void	conf_init (void);
@@ -114,7 +117,6 @@ void	conf_load (void);
  *
  * @returns boolean value (FALSE on failure)
  */
-#define getBooleanConfValue(key) conf_get_bool_value(key)
 gboolean conf_get_bool_value (const gchar *key);
 
 /**
@@ -124,7 +126,6 @@ gboolean conf_get_bool_value (const gchar *key);
  *
  * @returns string value (NULL on failure, to be free'd using g_free)
  */
-#define getStringConfValue(key) conf_get_str_value(key)
 gchar *	conf_get_str_value (const gchar *key);
 
 /**
@@ -134,7 +135,6 @@ gchar *	conf_get_str_value (const gchar *key);
  *
  * @returns integer value (0 on failure)
  */
-#define getNumericConfValue(key) conf_get_int_value(key)
 gint conf_get_int_value (const gchar *key);
 
 /**
@@ -143,7 +143,6 @@ gint conf_get_int_value (const gchar *key);
  * @param key	the configuration key
  * @param value	the new boolean value
  */
-#define setBooleanConfValue(key,value) conf_set_bool_value(key,value)
 void conf_set_bool_value (const gchar *key, gboolean value);
 
 /**
@@ -153,7 +152,6 @@ void conf_set_bool_value (const gchar *key, gboolean value);
  * @param key	the configuration key
  * @param value	the new string value
  */
-#define setStringConfValue(key,value) conf_set_str_value(key,value)
 void conf_set_str_value (const gchar *key, const gchar *value);
 
 /**
@@ -162,7 +160,6 @@ void conf_set_str_value (const gchar *key, const gchar *value);
  * @param key	the configuration key
  * @param value	the new integer value
  */
-#define setNumericConfValue(key,value) conf_set_int_value(key,value)
 void conf_set_int_value (const gchar *key, gint value);
 
 /**
