@@ -1,7 +1,7 @@
 /**
  * @file db.h sqlite backend 
  * 
- * Copyright (C) 2007  Lars Lindner <lars.lindner@gmail.com>
+ * Copyright (C) 2007-2008  Lars Lindner <lars.lindner@gmail.com>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -23,6 +23,7 @@
 
 #include <glib.h>
 
+#include "attention.h"
 #include "item.h"
 #include "itemlist.h"
 #include "itemset.h"
@@ -31,10 +32,8 @@
 
 /**
  * Open and initialize the DB.
- *
- * @param initial	TRUE for initial opening
  */
-void db_init(gboolean initial);
+void db_init(void);
 
 /**
  * Clean up and close the DB.
@@ -62,11 +61,10 @@ void		db_itemset_remove_all(const gchar *id);
 
 /**
  * Mass items state changing methods. Mark all items of
- * a given item set as read/updated/old/popup.
+ * a given item set as old/popup.
  *
  * @param id	the node id
  */
-void		db_itemset_mark_all_updated(const gchar *id);
 void		db_itemset_mark_all_old(const gchar *id);
 void		db_itemset_mark_all_popup(const gchar *id);
 
@@ -122,12 +120,11 @@ void	db_item_update(itemPtr item);
 void	db_item_remove(gulong id);
 
 /**
- * Marks a single item as read. If the item has a valid GUID
- * it will mark all duplicates read.
+ * Update the attributes related to item state only.
  *
- * @param item		the item
+ * @param item          the item
  */
-void	db_item_mark_read (itemPtr item);
+void    db_item_state_update (itemPtr item);
 
 /**
  * Returns a list of item ids with the given GUID. 
@@ -290,13 +287,6 @@ void db_subscription_update (subscriptionPtr subscription);
  */
 void db_subscription_remove (const gchar *id);
 
-/**
- * Returns a list of all subscription node ids.
- *
- * @returns a list of strings (values must be free'd by caller)
- */
-GSList * db_subscription_list_load (void);
-
 /**
  * Loads the node with the given node id from the DB.
  *
@@ -318,4 +308,19 @@ void db_node_update (nodePtr node);
  */
 void db_node_remove (nodePtr node);
 
+/**
+ * Saves the attention statistics of a given category.
+ *
+ * @param stat	category statistic info
+ */
+void db_attention_stat_save (categoryStatPtr stat);
+
+/**
+ * Loads attention statistics of all categories.
+ *
+ * @param statHash	a hash table to add all category statistics.
+ * @param statList	a list to add all category statistics
+ */
+void db_attention_stats_load (GHashTable **statHash, GSList **statList);
+
 #endif
