@@ -51,6 +51,7 @@ debug_get_prefix (unsigned long flag)
 	if (flag & DEBUG_TRACE)		return "TRACE";
 	if (flag & DEBUG_NET)		return "NET";
 	if (flag & DEBUG_DB)		return "DB";
+	if (flag & DEBUG_PERF)		return "PERF";
 	return "";	
 }
 
@@ -79,10 +80,11 @@ debug_start_measurement_func (const char * function)
 void
 debug_end_measurement_func (const char * function,
                             unsigned long flags, 
-			    gchar *name)
+			    const char *name)
 {
 	GTimeVal	*startTime = NULL;
 	GTimeVal	endTime;
+	unsigned long	duration = 0;
 		
 	if (!function)
 		return;
@@ -105,6 +107,10 @@ debug_end_measurement_func (const char * function,
 	g_print ("%s: %s took %01ld,%03lds\n", debug_get_prefix (flags), name, 
 	                                     endTime.tv_sec - startTime->tv_sec, 
 					     endTime.tv_usec/1000);
+					     
+	duration = (endTime.tv_sec - startTime->tv_sec)*1000 + endTime.tv_usec/1000;
+	if (duration > 250)
+		debug2 (DEBUG_PERF, "function \"%s\" is slow! Took %dms.", name, duration);
 }
  
 void
@@ -185,3 +191,21 @@ debug_printf (const char    * strloc,
 
 	g_free (string);
 }
+
+void
+debug_enter (const char *name) 
+{
+	debug1 (DEBUG_TRACE, "+ %s", name);
+	
+	if (debug_level & DEBUG_PERF)
+		debug_start_measurement_func (name);
+}
+
+void
+debug_exit (const char *name)
+{
+	debug1 (DEBUG_TRACE, "- %s", name);
+	
+	if (debug_level & DEBUG_PERF)
+		debug_end_measurement_func (name, DEBUG_PERF, name);
+}
