@@ -1,5 +1,5 @@
 /**
- * @file htmlview.h implementation of the item view interface for HTML rendering
+ * @file htmlview.h  item view interface for HTML rendering
  * 
  * Copyright (C) 2006-2007 Lars Lindner <lars.lindner@gmail.com>
  *
@@ -22,9 +22,9 @@
 #define _HTMLVIEW_H
 
 #include "item.h"
-#include "itemview.h"
 #include "node.h"
-#include "ui/ui_htmlview.h"
+#include "ui/itemview.h"
+#include "ui/liferea_htmlview.h"
 
 /* interface for item and item set HTML rendering */
 
