@@ -40,7 +40,6 @@ static SoupSession *session;
 static SoupSession *session_no_proxy;
 static SoupSession *session_no_cookies;
 static SoupSession *session_no_cookies_no_proxy;
-static SoupURI *proxy = NULL;
 
 static gchar	*proxyname = NULL;
 static gchar	*proxyusername = NULL;
@@ -89,6 +88,24 @@ network_process_callback (SoupSession *session, SoupMessage *msg, gpointer user_
 	update_process_finished_job (job);
 }
 
+static SoupURI *
+network_get_proxy_uri (void)
+{
+	SoupURI *uri = NULL;
+	
+	if (!proxyname)
+		return uri;
+		
+	uri = soup_uri_new (NULL);
+	soup_uri_set_scheme (uri, SOUP_URI_SCHEME_HTTP);
+	soup_uri_set_host (uri, proxyname);
+	soup_uri_set_port (uri, proxyport);
+	soup_uri_set_user (uri, proxyusername);
+	soup_uri_set_password (uri, proxypassword);
+
+	return uri;
+}
+
 /* Downloads a feed specified in the request structure, returns 
    the downloaded data or NULL in the request structure.
    If the the webserver reports a permanent redirection, the
@@ -185,6 +202,22 @@ network_process_request (const updateJobPtr const job)
 	}
 }
 
+static void
+network_authenticate (
+	SoupSession *session,
+	SoupMessage *msg,
+        SoupAuth *auth,
+	gboolean retrying,
+	gpointer data)
+{
+	if (!retrying && msg->status_code == SOUP_STATUS_PROXY_UNAUTHORIZED) {
+		soup_auth_authenticate (auth, g_strdup (proxyusername), g_strdup (proxypassword));
+	}
+	
+	// FIXME: Handle HTTP 401 too
+}
+
+
 void
 network_init (void)
 {
@@ -192,6 +225,7 @@ network_init (void)
 	SoupCookieJar	*cookies;
 	gchar		*filename;
 	SoupLogger	*logger;
+	SoupURI		*proxy;
 
 	/* Set an appropriate user agent */
 	if (g_getenv ("LANG")) {
@@ -208,14 +242,21 @@ network_init (void)
 	g_free (filename);
 
 	/* Initialize libsoup */
+	proxy = network_get_proxy_uri ();
 	session = soup_session_async_new_with_options (SOUP_SESSION_USER_AGENT, useragent,
+	                                               SOUP_SESSION_TIMEOUT, 120,
 						       SOUP_SESSION_IDLE_TIMEOUT, 30,
 						       SOUP_SESSION_PROXY_URI, proxy,
 						       SOUP_SESSION_ADD_FEATURE, cookies,
 						       NULL);
+	if (proxy)
+		soup_uri_free (proxy);
+		
+	g_signal_connect (session, "authenticate", G_CALLBACK (network_authenticate), NULL);
 
 	/* This session is for those cases where we are told not to use the proxy */
 	session_no_proxy = soup_session_async_new_with_options (SOUP_SESSION_USER_AGENT, useragent,
+	                                                        SOUP_SESSION_TIMEOUT, 120,
 								SOUP_SESSION_IDLE_TIMEOUT, 30,
 								SOUP_SESSION_ADD_FEATURE, cookies,
 								NULL);
@@ -223,6 +264,7 @@ network_init (void)
 	/* This session is for those cases where we need to add specific cookies, e.g. Google Reader.
 	 * Once GNOME #574571 is fixed, we will be able to use the normal session */
 	session_no_cookies = soup_session_async_new_with_options (SOUP_SESSION_USER_AGENT, useragent,
+	                                                          SOUP_SESSION_TIMEOUT, 120,
 								  SOUP_SESSION_IDLE_TIMEOUT, 30,
 								  SOUP_SESSION_PROXY_URI, proxy,
 								  NULL);
@@ -230,6 +272,7 @@ network_init (void)
 	/* And this one is for cases where we need to use our own cookies, and bypass the proxy, e.g.
 	 * Google Reader subscription where the "ignore proxy" preference is set */
 	session_no_cookies_no_proxy = soup_session_async_new_with_options (SOUP_SESSION_USER_AGENT, useragent,
+	                                                                   SOUP_SESSION_TIMEOUT, 120,
 									   SOUP_SESSION_IDLE_TIMEOUT, 30,
 									   NULL);
 
@@ -277,8 +320,6 @@ network_get_proxy_password (void)
 void
 network_set_proxy (gchar *host, guint port, gchar *user, gchar *password)
 {
-	SoupURI *newproxy = NULL;
-
 	/* FIXME: make arguments const and use the SoupURI in network_get_proxy_* ? */
 	g_free (proxyname);
 	g_free (proxyusername);
@@ -288,35 +329,23 @@ network_set_proxy (gchar *host, guint port, gchar *user, gchar *password)
 	proxyusername = user;
 	proxypassword = password;
 
-	if (host) {
-		newproxy = soup_uri_new (NULL);
-		soup_uri_set_scheme (newproxy, SOUP_URI_SCHEME_HTTP);
-		soup_uri_set_host (newproxy, host);
-		soup_uri_set_port (newproxy, port);
-		soup_uri_set_user (newproxy, user);
-		soup_uri_set_password (newproxy, password);
-	}
-
 	/* The sessions will be NULL if we were called from conf_init() as that's called
 	 * before net_init() */
 	if (session) {
+		SoupURI *newproxy = network_get_proxy_uri ();
+		
 		g_object_set (session,
 			      SOUP_SESSION_PROXY_URI, newproxy,
 			      NULL);
 		g_object_set (session_no_cookies,
 			      SOUP_SESSION_PROXY_URI, newproxy,
 			      NULL);
+
+		if (newproxy)
+			soup_uri_free (newproxy);
 	}
 
-	if (proxy)
-		soup_uri_free (proxy);
-	proxy = newproxy;
-
-	if (proxy) {
-		debug1 (DEBUG_NET, "proxy set to %s", soup_uri_to_string (proxy, FALSE));
-	} else {
-		debug0 (DEBUG_NET, "proxy unset!");
-	}
+	debug4 (DEBUG_NET, "proxy set to http://%s:%s@%s:%d", user, password, host, port);
 
 	liferea_htmlview_update_proxy ();
 }
