@@ -1,7 +1,7 @@
 /**
  * @file cdf_channel.c CDF channel parsing
  *
- * Copyright (C) 2003-2007 Lars Lindner <lars.lindner@gmail.com>
+ * Copyright (C) 2003-2009 Lars Lindner <lars.lindner@gmail.com>
  * 
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -18,10 +18,6 @@
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
 
-#ifdef HAVE_CONFIG_H
-#  include <config.h>
-#endif
-
 /* CDF is evil. There is only one outdated specification of it and its
    example is not even well-formed XML! Also, it seems to rely on
    things being case insensitive. Some people seem to make the tags
@@ -32,7 +28,6 @@
 #include <libxml/xmlmemory.h>
 #include <libxml/parser.h>
 #include "common.h"
-#include "feed.h"
 #include "feedlist.h"
 #include "cdf_channel.h"
 #include "cdf_item.h"
@@ -54,17 +49,17 @@ static void parseCDFChannel(feedParserCtxtPtr ctxt, xmlNodePtr cur, CDFChannelPt
 		}
 
 		if((!xmlStrcasecmp(cur->name, BAD_CAST"logo"))) {
-			tmp = common_utf8_fix(xmlGetProp(cur, BAD_CAST"HREF"));
+			tmp = common_utf8_fix((gchar *)xmlGetProp(cur, BAD_CAST"HREF"));
 			if(tmp) {
-				tmp = common_utf8_fix(xmlGetProp(cur, BAD_CAST"href"));
-				feed_set_image_url(ctxt->feed, tmp);
+				tmp = common_utf8_fix((gchar *)xmlGetProp(cur, BAD_CAST"href"));
+				metadata_list_set (&ctxt->subscription->metadata, "imageUrl", tmp);
 				g_free(tmp);
 			}
 
 		} else if((!xmlStrcasecmp(cur->name, BAD_CAST"a"))) {
 			xmlChar *value = xmlGetProp(cur, BAD_CAST"HREF");
 			if(value) {
-				feed_set_html_url(ctxt->feed, subscription_get_source(ctxt->subscription), (gchar *)value);
+				subscription_set_homepage (ctxt->subscription, (gchar *)value);
 				xmlFree(value);
 			}
 
@@ -77,7 +72,7 @@ static void parseCDFChannel(feedParserCtxtPtr ctxt, xmlNodePtr cur, CDFChannelPt
 			}
 
 		} else if(!xmlStrcasecmp(cur->name, BAD_CAST "title")) {
-			tmp = common_utf8_fix(xmlNodeListGetString(cur->doc, cur->xmlChildrenNode, TRUE));
+			tmp = common_utf8_fix((gchar *)xmlNodeListGetString(cur->doc, cur->xmlChildrenNode, TRUE));
 			if(tmp) {
 				tmp = unhtmlize(tmp);
 				
@@ -87,7 +82,7 @@ static void parseCDFChannel(feedParserCtxtPtr ctxt, xmlNodePtr cur, CDFChannelPt
 			}
 			
 		} else if (!xmlStrcasecmp(cur->name, BAD_CAST "abstract")) {
-			tmp = common_utf8_fix (xmlNodeListGetString (cur->doc, cur->xmlChildrenNode, TRUE));
+			tmp = common_utf8_fix ((gchar *)xmlNodeListGetString (cur->doc, cur->xmlChildrenNode, TRUE));
 			if (tmp) {
 				metadata_list_set (&ctxt->subscription->metadata, "description", tmp);
 				xmlFree (tmp);
@@ -97,7 +92,7 @@ static void parseCDFChannel(feedParserCtxtPtr ctxt, xmlNodePtr cur, CDFChannelPt
 			tmp = g_ascii_strdown((gchar *)cur->name, -1);
 			tmp2 = g_hash_table_lookup(channelHash, tmp);
 			if(tmp2) {
-				tmp3 = common_utf8_fix(xmlNodeListGetString(cur->doc, cur->xmlChildrenNode, TRUE));
+				tmp3 = common_utf8_fix((gchar *)xmlNodeListGetString(cur->doc, cur->xmlChildrenNode, TRUE));
 				if(tmp3) {
 					ctxt->subscription->metadata = metadata_list_append(ctxt->subscription->metadata, tmp2, tmp3);
 					g_free(tmp3);
@@ -148,7 +143,7 @@ static void cdf_parse(feedParserCtxtPtr ctxt, xmlNodePtr cur) {
 	} while (FALSE);
 }
 
-gboolean cdf_format_check(xmlDocPtr doc, xmlNodePtr cur) {
+static gboolean cdf_format_check(xmlDocPtr doc, xmlNodePtr cur) {
 		
 	/* avoid mistaking RSS 1.1 which also uses "Channel" as root tag */
 	if((NULL != cur->ns) &&
