@@ -1,7 +1,7 @@
 /**
- * @file subscription.h common subscription handling interface
+ * @file subscription.h  common subscription handling interface
  * 
- * Copyright (C) 2003-2007 Lars Lindner <lars.lindner@gmail.com>
+ * Copyright (C) 2003-2009 Lars Lindner <lars.lindner@gmail.com>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -25,15 +25,22 @@
 #include "node.h"
 #include "update.h"
 
+/** Caching property constants */
+enum cache_limit {
+	/* Values > 0 are used to specify certain limits */
+	CACHE_DISABLE = 0,
+	CACHE_DEFAULT = -1,
+	CACHE_UNLIMITED = -2,
+};
+
 /** Flags used in the request structure */
 enum feed_request_flags {
 	FEED_REQ_RESET_TITLE		= (1<<0),	/**< Feed's title should be reset to default upon update */
-	FEED_REQ_RESET_UPDATE_INT	= (1<<1),	/**< Feed's update interval should be reset to default upon update */
-	FEED_REQ_AUTO_DISCOVER		= (1<<2),	/**< Feed auto-discovery attempts should be made */
-	
+	/* FEED_REQ_RESET_UPDATE_INT is not used anymore */
+	/* FEED_REQ_AUTO_DISCOVER is not used anymore */
 	FEED_REQ_PRIORITY_HIGH		= (1<<3),	/**< set to signal that this is an important user triggered request */
-	FEED_REQ_DOWNLOAD_FAVICON	= (1<<4),	/**< set to make the favicon be updated after the feed is downloaded */
-	FEED_REQ_AUTH_DIALOG		= (1<<5),	/**< set to make an auth request dialog to be created after 401 errors */
+	/* FEED_REQ_DOWNLOAD_FAVICON is not used anymore */
+	/* FEED_REQ_AUTH_DIALOG is not used anymore */
 	FEED_REQ_ALLOW_RETRIES		= (1<<6),	/**< set to allow fetch retries on network errors */
 	FEED_REQ_NO_PROXY		= (1<<7)	/**< sets no proxy flag */
 };
@@ -41,6 +48,7 @@ enum feed_request_flags {
 /** Common structure to hold all information about a single subscription. */
 typedef struct subscription {
 	nodePtr		node;			/**< the feed list node the subscription is attached to */
+	struct subscriptionType *type;		/**< the subscription type */
 	
 	gchar		*source;		/**< current source, can be changed by redirects */
 	gchar		*origSource;		/**< the source given when creating the subscription */
@@ -48,7 +56,7 @@ typedef struct subscription {
 	struct updateJob *updateJob;		/**< update request structure used when downloading the subscribed source */
 	
 	gint		updateInterval;		/**< user defined update interval in minutes */	
-	guint		defaultInterval;	/**< optional update interval as specified by the feed */
+	guint		defaultInterval;	/**< optional update interval as specified by the feed in minutes */
 	
 	GSList		*metadata;		/**< metadata list assigned to this subscription */
 	
@@ -104,6 +112,14 @@ subscriptionPtr subscription_import (xmlNodePtr xml, gboolean trusted);
  */
 void subscription_export (subscriptionPtr subscription, xmlNodePtr xml, gboolean trusted);
 
+/**
+ * Serialization helper function for rendering purposes.
+ *
+ * @param node		the subscription to serialize
+ * @param feedNode	XML node to add subscription attributes to
+ */
+void subscription_to_xml (subscriptionPtr subscription, xmlNodePtr xml);
+
 /**
  * Checks wether a subscription is ready to be updated
  *
@@ -124,17 +140,6 @@ gboolean subscription_can_be_updated(subscriptionPtr subscription);
  */
 void subscription_update (subscriptionPtr subscription, guint flags);
 
-/**
- * Like subscription_update() updates a given subscription, but
- * allows to specify another result processing callback then the
- * one defined by the node type of the subscription.
- *
- * @param subscription	the subscription
- * @param callback	the callback
- * @param flags		update flags
- */
-void subscription_update_with_callback (subscriptionPtr subscription, subscription_update_cb callback, guint flags);
-
 /**
  * Called when auto updating. Checks wether the subscription
  * needs to be updated (according to it's update interval) and
@@ -144,12 +149,21 @@ void subscription_update_with_callback (subscriptionPtr subscription, subscripti
  */
 void subscription_auto_update (subscriptionPtr subscription);
 
+/**
+ * Cancels a currently running subscription update. This is to
+ * be called when removing subscriptions or retriggering the update
+ * upon user request.
+ *
+ * @param subscription	the subscription
+ */
+void subscription_cancel_update (subscriptionPtr subscription);
+
 /**
  * Get the update interval setting of a given subscription
  *
  * @param subscription	the subscription
  *
- * @returns the currently configured update interval (in seconds)
+ * @returns the currently configured update interval (in minutes)
  */
 gint subscription_get_update_interval(subscriptionPtr subscription);
 
@@ -157,7 +171,7 @@ gint subscription_get_update_interval(subscriptionPtr subscription);
  * Set the update interval setting for the given subscription
  *
  * @param subscription	the subscription
- * @param interval	the new update interval (in seconds)
+ * @param interval	the new update interval (in minutes)
  */
 void subscription_set_update_interval(subscriptionPtr subscription, gint interval);
 
@@ -166,7 +180,7 @@ void subscription_set_update_interval(subscriptionPtr subscription, gint interva
  *
  * @param subscription	the subscription
  *
- * @returns the default update interval (in seconds) or 0
+ * @returns the default update interval (in minutes) or 0
  */
 guint subscription_get_default_update_interval(subscriptionPtr subscription);
 
@@ -174,7 +188,7 @@ guint subscription_get_default_update_interval(subscriptionPtr subscription);
  * Set the default update interval setting for the given subscription
  *
  * @param subscription	the subscription
- * @param interval	the default update interval (in seconds)
+ * @param interval	the default update interval (in minutes)
  */
 void subscription_set_default_update_interval(subscriptionPtr subscription, guint interval);
 
@@ -185,21 +199,7 @@ void subscription_set_default_update_interval(subscriptionPtr subscription, guin
  */
 void subscription_reset_update_counter (subscriptionPtr subscription, GTimeVal *now);
 
-/**
- * Allows to explicitely set the cookies for the next 
- * update request. This method needs to be called after
- * subscription_set_source() which always resets the cookies
- * property. Note: update requests handled by the default
- * subscription result processing callback will overwrite
- * the cookies again in case of permanent redirects, so it
- * is necessary to set cookies before each request if 
- * different cookies than the source specific ones are
- * necessary.
- *
- * @param subscription	the subscription
- * @param cookies	the cookies
- */
-void subscription_set_cookies (subscriptionPtr subscription, const gchar *cookies);
+void subscription_update_favicon (subscriptionPtr subscription);
 
 /**
  * Get the source URL of a given subscription
@@ -235,6 +235,25 @@ const gchar * subscription_get_orig_source(subscriptionPtr subscription);
  */ 
 void subscription_set_orig_source(subscriptionPtr subscription, const gchar *source);
 
+/**
+ * Returns the homepage URL of the given subscription.
+ *
+ * @param subscription	the subscription
+ *
+ * @returns the homepage URL or NULL
+ */
+const gchar * subscription_get_homepage(subscriptionPtr subscription);
+
+/**
+ * Set the homepage URL of the given subscription. If the passed
+ * URL is a relative one it will be expanded using the
+ * given base URL.
+ *
+ * @param subscription	the subscription
+ * @param url		the new HTML URL
+ */
+void subscription_set_homepage(subscriptionPtr subscription, const gchar *url);
+
 /**
  * Get the configured filter command for a given subscription
  *
@@ -252,16 +271,6 @@ const gchar * subscription_get_filter(subscriptionPtr subscription);
  */
 void subscription_set_filter(subscriptionPtr subscription, const gchar * filter);
 
-/**
- * Updates the error status of the given subscription
- *
- * @param subscription	the subscription
- * @param httpstatus	the new HTTP status code
- * @param resultcode	the update result code
- * @param filterError	filter error string (or NULL)
- */
-void subscription_update_error_status(subscriptionPtr subscription, gint httpstatus, gint resultcode, gchar *filterError);
-
 /**
  * Frees the given subscription structure.
  *
