@@ -190,6 +190,9 @@ on_ruletype_changed (GtkOptionMenu *optionmenu, gpointer user_data)
 	ruleInfoPtr		ruleInfo;
 	rulePtr			rule;
 	
+	if (!changeRequest)
+		return;
+	
 	rule = g_object_get_data (G_OBJECT (changeRequest->paramHBox), "rule");
 	if (rule) {
 		changeRequest->editor->priv->newRules = g_slist_remove (changeRequest->editor->priv->newRules, rule);
@@ -225,9 +228,12 @@ rule_editor_add_rule (RuleEditor *re, rulePtr rule)
 	struct changeRequest	*changeRequest, *selected = NULL;
 	ruleInfoPtr		ruleInfo;
 	gint			i;
-
+	
 	hbox = gtk_hbox_new (FALSE, 2);	/* hbox to contain all rule widgets */
 	hbox2 = gtk_hbox_new (FALSE, 2);	/* another hbox where the rule specific widgets are added */
+
+	if (nrOfRuleFunctions == 0)
+		rule_init();
 		
 	/* set up the rule type selection popup */
 	menu = gtk_menu_new ();
