@@ -1,7 +1,7 @@
 /**
- * @file ui_subscription.c subscription dialogs
+ * @file ui_subscription.c  default subscription dialogs for feed subscriptions
  *
- * Copyright (C) 2004-2008 Lars Lindner <lars.lindner@gmail.com>
+ * Copyright (C) 2004-2009 Lars Lindner <lars.lindner@gmail.com>
  * Copyright (C) 2004-2006 Nathan J. Conrad <t98502@users.sourceforge.net>
  *
  * This program is free software; you can redistribute it and/or modify
@@ -18,12 +18,9 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
- 
-#ifdef HAVE_CONFIG_H
-#  include <config.h>
-#endif
 
-#include <gtk/gtk.h>
+#include "ui/ui_subscription.h"
+
 #include <libxml/uri.h>
 #include <string.h> 
 
@@ -35,16 +32,24 @@
 #include "feedlist.h"
 #include "node.h"
 #include "update.h"
-#include "ui/ui_dialog.h"
-#include "ui/ui_mainwindow.h"	/* for ui_choose_file() */
+#include "ui/liferea_dialog.h"
+#include "ui/ui_common.h"
 #include "ui/ui_node.h"
-#include "ui/ui_subscription.h"
+
+/* Note: these update interval literals should be kept in sync with the 
+   ones in ui_prefs.c! */
+    
+static gchar * default_update_interval_unit_options[] = {
+	N_("minutes"),
+	N_("hours"),
+	N_("days"),
+	NULL
+};
 
 /** common private structure for all subscription dialogs */
 struct SubscriptionDialogPrivate {
 
 	subscriptionPtr subscription;	/** used only for "properties" dialog */
-	nodePtr		parentNode;	/** used only for "new" dialogs */
 
 	gint selector; /* Desiginates which fileselection dialog box is open.
 				   Set to 'u' for source
@@ -268,14 +273,21 @@ on_propdialog_response (GtkDialog *dialog,
 		subscription->updateOptions->dontUseProxy = gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(liferea_dialog_lookup(GTK_WIDGET(dialog), "dontUseProxyCheck")));
 
 		/* "Advanced" options */
-		feed->encAutoDownload = gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(liferea_dialog_lookup(GTK_WIDGET(dialog), "enclosureDownloadCheck")));
-		feed->loadItemLink = gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(liferea_dialog_lookup(GTK_WIDGET(dialog), "loadItemLinkCheck")));
+		feed->encAutoDownload = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (liferea_dialog_lookup (GTK_WIDGET (dialog), "enclosureDownloadCheck")));
+		feed->loadItemLink = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (liferea_dialog_lookup (GTK_WIDGET (dialog), "loadItemLinkCheck")));
+		feed->ignoreComments = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (liferea_dialog_lookup (GTK_WIDGET (dialog), "ignoreCommentFeeds")));
+		feed->enforcePopup = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (liferea_dialog_lookup (GTK_WIDGET (dialog), "enforcePopupCheck")));
+		feed->preventPopup = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (liferea_dialog_lookup (GTK_WIDGET (dialog), "preventPopupCheck")));
+		feed->markAsRead = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (liferea_dialog_lookup (GTK_WIDGET (dialog), "markAsReadCheck")));
+		
+		if (feed->enforcePopup && feed->preventPopup)
+			feed->enforcePopup = FALSE;
 
 		ui_node_update (node->id);
 		feedlist_schedule_save ();
 		db_subscription_update (subscription);
 		if (needsUpdate)
-			subscription_update (subscription, FEED_REQ_AUTH_DIALOG | FEED_REQ_PRIORITY_HIGH);
+			subscription_update (subscription, FEED_REQ_PRIORITY_HIGH);
 	}
 
 	g_object_unref(spd);
@@ -399,7 +411,7 @@ ui_subscription_prop_dialog_load (SubscriptionPropDialog *spd,
                                   subscriptionPtr subscription) 
 {
 	gint 		interval;
-	guint		defaultInterval, spinSetInterval;
+	gint		defaultInterval, spinSetInterval;
 	gchar 		*defaultIntervalStr;
 	nodePtr		node = subscription->node;
 	feedPtr		feed = (feedPtr)node->data;
@@ -413,7 +425,7 @@ ui_subscription_prop_dialog_load (SubscriptionPropDialog *spd,
 	
 	interval = subscription_get_update_interval(subscription);
 	defaultInterval = subscription_get_default_update_interval(subscription);
-	spinSetInterval = defaultInterval;
+	spinSetInterval = defaultInterval > 0 ? defaultInterval : conf_get_int_value (DEFAULT_UPDATE_INTERVAL);
 	
 	if (-2 >= interval) {
 		gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (liferea_dialog_lookup(spd->priv->dialog, "updateIntervalNever")), TRUE);
@@ -515,8 +527,13 @@ ui_subscription_prop_dialog_load (SubscriptionPropDialog *spd,
 	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(liferea_dialog_lookup(spd->priv->dialog, "dontUseProxyCheck")), subscription->updateOptions->dontUseProxy);
 
 	/* Advanced */	
-	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(liferea_dialog_lookup(spd->priv->dialog, "enclosureDownloadCheck")), feed->encAutoDownload);
-	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(liferea_dialog_lookup(spd->priv->dialog, "loadItemLinkCheck")), feed->loadItemLink);
+	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (liferea_dialog_lookup (spd->priv->dialog, "enclosureDownloadCheck")), feed->encAutoDownload);
+	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (liferea_dialog_lookup (spd->priv->dialog, "loadItemLinkCheck")), feed->loadItemLink);
+	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (liferea_dialog_lookup (spd->priv->dialog, "ignoreCommentFeeds")), feed->ignoreComments);
+	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (liferea_dialog_lookup (spd->priv->dialog, "enforcePopupCheck")), feed->enforcePopup);
+	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (liferea_dialog_lookup (spd->priv->dialog, "preventPopupCheck")), feed->preventPopup);
+	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (liferea_dialog_lookup (spd->priv->dialog, "markAsReadCheck")), feed->markAsRead);
+
 }
 
 static void
@@ -526,7 +543,13 @@ subscription_prop_dialog_init (SubscriptionPropDialog *spd)
 	
 	spd->priv = SUBSCRIPTION_PROP_DIALOG_GET_PRIVATE (spd);
 	spd->priv->dialog = propdialog = liferea_dialog_new (NULL, "propdialog");
-	
+
+	/* set default update interval spin button and unit combo box */
+	ui_common_setup_combo_menu (liferea_dialog_lookup (propdialog, "refreshIntervalUnitComboBox"),
+	                            default_update_interval_unit_options,
+	                            NULL /* no callback */,
+	                            -1 /* default value */ );	
+
 	spd->priv->feedNameEntry = liferea_dialog_lookup (propdialog, "feedNameEntry");
 	spd->priv->refreshInterval = liferea_dialog_lookup (propdialog, "refreshIntervalSpinButton");
 	spd->priv->refreshIntervalUnit = liferea_dialog_lookup (propdialog, "refreshIntervalUnitComboBox");
@@ -625,41 +648,35 @@ new_subscription_dialog_class_init (NewSubscriptionDialogClass *klass)
 }
 
 static void
-on_newdialog_response (GtkDialog *dialog,
-                       gint response_id, 
-		       gpointer user_data) 
+on_newdialog_response (GtkDialog *dialog, gint response_id, gpointer user_data) 
 {
 	NewSubscriptionDialog *nsd = (NewSubscriptionDialog *)user_data;
 	
-	if(response_id == GTK_RESPONSE_OK) {
+	if (response_id == GTK_RESPONSE_OK) {
 		gchar *source = NULL;
 		const gchar *filter = NULL;
 		updateOptionsPtr options;
 
 		/* Source */
-		source = ui_subscription_dialog_decode_source(nsd->priv);
+		source = ui_subscription_dialog_decode_source (nsd->priv);
 
 		/* Filter handling */
-		filter = gtk_entry_get_text(GTK_ENTRY(liferea_dialog_lookup(nsd->priv->dialog, "filterEntry")));
-		if(!gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(liferea_dialog_lookup(nsd->priv->dialog, "filterCheckbox"))) ||
-		   !strcmp(filter,"")) { /* Maybe this should be a test to see if the file exists? */
+		filter = gtk_entry_get_text (GTK_ENTRY (liferea_dialog_lookup (nsd->priv->dialog, "filterEntry")));
+		if (!gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (liferea_dialog_lookup (nsd->priv->dialog, "filterCheckbox"))) ||
+		    !strcmp(filter,"")) { /* Maybe this should be a test to see if the file exists? */
 			filter = NULL;
 		} 
 		
-		options = g_new0(struct updateOptions, 1);
-		options->dontUseProxy = gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(liferea_dialog_lookup(GTK_WIDGET(dialog), "dontUseProxyCheck")));
+		options = g_new0 (struct updateOptions, 1);
+		options->dontUseProxy = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (liferea_dialog_lookup(GTK_WIDGET (dialog), "dontUseProxyCheck")));
 		
-		node_request_automatic_add(source, NULL, filter, options,
+		feedlist_add_subscription (source, filter, options,
 					   FEED_REQ_RESET_TITLE | 
-					   FEED_REQ_RESET_UPDATE_INT | 
-					   FEED_REQ_AUTO_DISCOVER | 
-					   FEED_REQ_PRIORITY_HIGH | 
-					   FEED_REQ_DOWNLOAD_FAVICON | 
-					   FEED_REQ_AUTH_DIALOG);
-		g_free(source);
+					   FEED_REQ_PRIORITY_HIGH);
+		g_free (source);
 	}
 
-	g_object_unref(nsd);
+	g_object_unref (nsd);
 }
 
 static void
@@ -668,7 +685,7 @@ new_subscription_dialog_init (NewSubscriptionDialog *nsd)
 	GtkWidget	*newdialog;
 	
 	nsd->priv = NEW_SUBSCRIPTION_DIALOG_GET_PRIVATE (nsd);
-	nsd->priv->dialog = newdialog = liferea_dialog_new (NULL, "newdialog");
+	nsd->priv->dialog = newdialog = liferea_dialog_new ("new_subscription.glade", "newdialog");
 	
 	/* Setup source entry */
 	nsd->priv->sourceEntry = liferea_dialog_lookup (newdialog,"sourceEntry");
@@ -700,12 +717,11 @@ new_subscription_dialog_init (NewSubscriptionDialog *nsd)
 }
 
 NewSubscriptionDialog *
-ui_complex_subscription_dialog_new (nodePtr parent) 
+ui_complex_subscription_dialog_new (void) 
 {
 	NewSubscriptionDialog *nsd;
 	
 	nsd = NEW_SUBSCRIPTION_DIALOG (g_object_new (NEW_SUBSCRIPTION_DIALOG_TYPE, NULL));
-	nsd->priv->parentNode = parent;
 	return nsd;
 }
 
@@ -767,29 +783,23 @@ simple_subscription_dialog_class_init (SimpleSubscriptionDialogClass *klass)
 }
 
 static void
-on_simple_newdialog_response (GtkDialog *dialog,
-                              gint response_id,
-			      gpointer user_data) 
+on_simple_newdialog_response (GtkDialog *dialog, gint response_id, gpointer user_data) 
 {
 	SimpleSubscriptionDialog *ssd = (SimpleSubscriptionDialog *)user_data;
 	gchar *source = NULL;
 	
 	if (response_id == GTK_RESPONSE_OK) {
-		source = ui_subscription_create_url( g_strdup (gtk_entry_get_text (GTK_ENTRY(ssd->priv->sourceEntry))),
-		                                     FALSE /* auth */, NULL /* user */, NULL /* passwd */);
+		source = ui_subscription_create_url (g_strdup (gtk_entry_get_text (GTK_ENTRY(ssd->priv->sourceEntry))),
+		                                      FALSE /* auth */, NULL /* user */, NULL /* passwd */);
 
-		node_request_automatic_add(source, NULL, NULL, NULL,
+		feedlist_add_subscription (source, NULL, NULL,
 					   FEED_REQ_RESET_TITLE | 
-					   FEED_REQ_RESET_UPDATE_INT | 
-					   FEED_REQ_AUTO_DISCOVER | 
-					   FEED_REQ_PRIORITY_HIGH | 
-					   FEED_REQ_DOWNLOAD_FAVICON | 
-					   FEED_REQ_AUTH_DIALOG);
-		g_free(source);
+					   FEED_REQ_PRIORITY_HIGH);
+		g_free (source);
 	}
 	
 	if (response_id == GTK_RESPONSE_APPLY) /* misused for "Advanced" */
-		ui_complex_subscription_dialog_new (ssd->priv->parentNode);
+		ui_complex_subscription_dialog_new ();
 		
 	g_object_unref (ssd);
 }
@@ -800,7 +810,7 @@ simple_subscription_dialog_init (SimpleSubscriptionDialog *ssd)
 	GtkWidget	*newdialog;
 	
 	ssd->priv = SIMPLE_SUBSCRIPTION_DIALOG_GET_PRIVATE (ssd);
-	ssd->priv->dialog = newdialog = liferea_dialog_new (NULL, "simplenewdialog");
+	ssd->priv->dialog = newdialog = liferea_dialog_new ("simple_subscription.glade", "simplenewdialog");
 	
 	/* Setup source entry */
 	ssd->priv->sourceEntry = liferea_dialog_lookup (newdialog, "sourceEntry");
@@ -814,11 +824,10 @@ simple_subscription_dialog_init (SimpleSubscriptionDialog *ssd)
 }
 
 SimpleSubscriptionDialog *
-ui_subscription_dialog_new (nodePtr parent) 
+ui_subscription_dialog_new (void) 
 {
 	SimpleSubscriptionDialog *ssd;
 	
 	ssd = SIMPLE_SUBSCRIPTION_DIALOG (g_object_new (SIMPLE_SUBSCRIPTION_DIALOG_TYPE, NULL));
-	ssd->priv->parentNode = parent;
 	return ssd;
 }
